from typing import Literal

BackdropBrightness = Literal[
    '0',
    '50',
    '75',
    '90',
    '95',
    '100',
    '105',
    '110',
    '125',
    '150',
    '200',
]
